@@ -6,7 +6,8 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{CmdError, Error, QueryResponse};
+use super::{CmdError, Error, QueryResponse, Result};
+use crate::messaging::data::OperationId;
 use crate::types::{
     register::{Address, Entry, Register, RegisterOp, User},
     PublicKey,
@@ -84,20 +85,43 @@ pub enum RegisterWrite {
 impl RegisterRead {
     /// Creates a Response containing an error, with the Response variant corresponding to the
     /// Request variant.
-    pub fn error(&self, error: Error) -> QueryResponse {
+    pub fn error(&self, error: Error) -> Result<QueryResponse> {
         match *self {
-            RegisterRead::Get(_) => QueryResponse::GetRegister(Err(error)),
-            RegisterRead::Read(_) => QueryResponse::ReadRegister(Err(error)),
-            RegisterRead::GetPolicy(_) => QueryResponse::GetRegisterPolicy(Err(error)),
-            RegisterRead::GetUserPermissions { .. } => {
-                QueryResponse::GetRegisterUserPermissions(Err(error))
-            }
-            RegisterRead::GetOwner(_) => QueryResponse::GetRegisterOwner(Err(error)),
+            RegisterRead::Get(_) => Ok(QueryResponse::GetRegister((
+                Err(error),
+                self.operation_id()?,
+            ))),
+            RegisterRead::Read(_) => Ok(QueryResponse::ReadRegister((
+                Err(error),
+                self.operation_id()?,
+            ))),
+            RegisterRead::GetPolicy(_) => Ok(QueryResponse::GetRegisterPolicy((
+                Err(error),
+                self.operation_id()?,
+            ))),
+            RegisterRead::GetUserPermissions { .. } => Ok(
+                QueryResponse::GetRegisterUserPermissions((Err(error), self.operation_id()?)),
+            ),
+            RegisterRead::GetOwner(_) => Ok(QueryResponse::GetRegisterOwner((
+                Err(error),
+                self.operation_id()?,
+            ))),
         }
     }
 
-    /// Returns the address of the destination for request.
-    pub fn dst_address(&self) -> XorName {
+    /// Returns the address of the data for request. (Scoped to Private/Public)
+    pub fn dst_address(&self) -> Address {
+        match self {
+            RegisterRead::Get(ref address)
+            | RegisterRead::Read(ref address)
+            | RegisterRead::GetPolicy(ref address)
+            | RegisterRead::GetUserPermissions { ref address, .. }
+            | RegisterRead::GetOwner(ref address) => *address,
+        }
+    }
+
+    /// Returns the xorname of the data for request.
+    pub fn dst_name(&self) -> XorName {
         match self {
             RegisterRead::Get(ref address)
             | RegisterRead::Read(ref address)
@@ -106,6 +130,45 @@ impl RegisterRead {
             | RegisterRead::GetOwner(ref address) => *address.name(),
         }
     }
+
+    /// Retrieves the operation identifier for this response, use in tracking node liveness
+    /// and responses at clients.
+    /// Must be the same as the query response
+    /// Right now returning result to fail for anything non-chunk, as that's all we're tracking from other nodes here just now.
+    pub fn operation_id(&self) -> Result<OperationId> {
+        match self {
+            RegisterRead::Get(ref address) => Ok(format!(
+                "Get-{:?}",
+                address
+                    .encode_to_zbase32()
+                    .map_err(|_| Error::NoOperationId)?
+            )),
+            RegisterRead::Read(ref address) => Ok(format!(
+                "Read-{:?}",
+                address
+                    .encode_to_zbase32()
+                    .map_err(|_| Error::NoOperationId)?
+            )),
+            RegisterRead::GetPolicy(ref address) => Ok(format!(
+                "GetPolicy-{:?}",
+                address
+                    .encode_to_zbase32()
+                    .map_err(|_| Error::NoOperationId)?
+            )),
+            RegisterRead::GetUserPermissions { ref address, .. } => Ok(format!(
+                "GetUserPermissions-{:?}",
+                address
+                    .encode_to_zbase32()
+                    .map_err(|_| Error::NoOperationId)?
+            )),
+            RegisterRead::GetOwner(ref address) => Ok(format!(
+                "GetOwner-{:?}",
+                address
+                    .encode_to_zbase32()
+                    .map_err(|_| Error::NoOperationId)?
+            )),
+        }
+    }
 }
 
 impl RegisterWrite {
@@ -116,7 +179,7 @@ impl RegisterWrite {
     }
 
     /// Returns the address of the destination for request.
-    pub fn dst_address(&self) -> XorName {
+    pub fn dst_name(&self) -> XorName {
         match self {
             RegisterWrite::New(ref data) => *data.name(),
             RegisterWrite::Delete(ref address) => *address.name(),
